@@ -207,7 +207,7 @@ sub get_default_config_settings
 
         foulwords => 'ass fuck bitch shit scheisse scheie kacke arsch ficker ficken schlampe',
         violentwords => 'slaps beats smacks',
-        chartsregexp => '(?:np:|(?:now )?playing:? (?:MPEG stream from)?)\s*(.*)',
+        chartsregexp => '(?:is )?(?:np:|(?:now )?playing:? |listening to:? )(?:MPEG stream from)?\s*(.*)',
         ignorewords => '',
         noignoredquotes => 0,
         tablewidth => 574,
@@ -219,7 +219,7 @@ sub get_default_config_settings
         modules_dir => '',         # set in get_cmdline_options
         cchannels => '',           # set in get_cmdline_options
 
-        version => "0.72",
+        version => "0.73"
     };
 
     # This enables us to use the search_path in other modules
